%INTERPOLADOR DE LOS ACF.
%function [av0,av1]=ACFav(ACFvad,av0ant)
%Entradas:
%ACFvad:ACF de las cuatro tramas anteriores.
%av0ant:av0 de las cuatro tramas anteriores.
%Salidas:
%av0:ACF de las cuatro tramas anteriores interpolados.
%av1:son iguales a los av0ant,para un posterior módulo.
function [av0,av1]=ACFav(ACFvad,av0ant)
i=1:9;
av0(i)=ACFvad(i)+ACFvad(i+9)+ACFvad(i+18)+ACFvad(i+27);
av1(i)=av0ant(i);